summaryrefslogtreecommitdiff
path: root/src/include/taler_mintdb_lib.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2015-09-19 16:34:27 +0200
committerChristian Grothoff <christian@grothoff.org>2015-09-19 16:34:27 +0200
commit37a84c5af7b466bef1d4ca4b18999e8b6ef590f2 (patch)
tree2b71b3b6f6371decf90065bb744c49f61582882d /src/include/taler_mintdb_lib.h
parent00b697c405d3d1dfae102eb1223cb07509f680a9 (diff)
downloadexchange-37a84c5af7b466bef1d4ca4b18999e8b6ef590f2.tar.gz
exchange-37a84c5af7b466bef1d4ca4b18999e8b6ef590f2.tar.bz2
exchange-37a84c5af7b466bef1d4ca4b18999e8b6ef590f2.zip
finish implementing #3847
Diffstat (limited to 'src/include/taler_mintdb_lib.h')
-rw-r--r--src/include/taler_mintdb_lib.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/include/taler_mintdb_lib.h b/src/include/taler_mintdb_lib.h
index b7f28cffe..7dfef8dc5 100644
--- a/src/include/taler_mintdb_lib.h
+++ b/src/include/taler_mintdb_lib.h
@@ -212,10 +212,10 @@ TALER_MINTDB_denomination_key_read (const char *filename,
*
* @param cls closure
* @param apub the auditor's public key
- * @param asig the auditor's signature
* @param mpub the mint's public key (as expected by the auditor)
* @param dki_len length of @a dki
* @param dki array of denomination coin data signed by the auditor
* @return #GNUNET_OK to continue to iterate,
* #GNUNET_NO to stop iteration with no error,
* #GNUNET_SYSERR to abort iteration with error!
@@ -223,9 +223,9 @@ TALER_MINTDB_denomination_key_read (const char *filename,
typedef int
(*TALER_MINTDB_AuditorIterator)(void *cls,
const struct TALER_AuditorPublicKeyP *apub,
- const struct TALER_AuditorSignatureP *asig,
const struct TALER_MasterPublicKeyP *mpub,
unsigned int dki_len,
+ const struct TALER_AuditorSignatureP *asigs,
const struct TALER_DenominationKeyValidityPS *dki);
@@ -253,16 +253,16 @@ TALER_MINTDB_auditor_iterate (const char *mint_base_dir,
*
* @param filename the file where to write the auditor information to
* @param apub the auditor's public key
- * @param asig the auditor's signature
+ * @param asigs the auditor's signatures, array of length @a dki_len
* @param mpub the mint's public key (as expected by the auditor)
* @param dki_len length of @a dki
* @param dki array of denomination coin data signed by the auditor
* @return #GNUNET_OK upon success; #GNUNET_SYSERR upon failure.
*/
int
TALER_MINTDB_auditor_write (const char *filename,
const struct TALER_AuditorPublicKeyP *apub,
- const struct TALER_AuditorSignatureP *asig,
+ const struct TALER_AuditorSignatureP *asigs,
const struct TALER_MasterPublicKeyP *mpub,
unsigned int dki_len,
const struct TALER_DenominationKeyValidityPS *dki);
@@ -212,10 +212,10 @@ TALER_MINTDB_denomination_key_read (const char *filename,
* @param mpub the mint's public key (as expected by the auditor)
- * @param dki_len length of @a dki
- * @param dki array of denomination coin data signed by the auditor
+ * @param dki_len length of @a asig and @a dki arrays
+ * @param asigs array of the auditor's signatures over the @a dks, of length @a dki_len
+ * @param dki array of denomination coin data signed by the auditor, of length @a dki_len
* @return #GNUNET_OK to continue to iterate,
* #GNUNET_NO to stop iteration with no error,
@@ -253,16 +253,16 @@ TALER_MINTDB_auditor_iterate (const char *mint_base_dir,
* @param mpub the mint's public key (as expected by the auditor)
- * @param dki_len length of @a dki
+ * @param dki_len length of @a dki and @a asigs arrays
* @param dki array of denomination coin data signed by the auditor
* @return #GNUNET_OK upon success; #GNUNET_SYSERR upon failure.